@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,18 +13,14 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import json
 import os
 import sys
 from contextlib import contextmanager
+from typing import Dict, Set, Tuple
 
 from hypothesis.internal.reflection import proxies
 
-if False:
-    from typing import Set, Dict, Tuple  # noqa
-
 """
 This module implements a custom coverage system that records conditions and
 then validates that every condition has been seen to be both True and False
@@ -50,7 +44,8 @@ def pretty_file_name(f):
         pass
 
     parts = f.split(os.path.sep)
-    parts = parts[-parts[::-1].index("hypothesis") :]
+    if "hypothesis" in parts:
+        parts = parts[-parts[::-1].index("hypothesis") :]
     result = os.path.sep.join(parts)
     pretty_file_name_cache[f] = result
     return result
